/**
 * @author Brace Stout
 * 
 * This software is copyright 2006, 2007 by StoutWare Engineering
 * All rights are retained.
 * 
 * This is example code only.  No representation is made
 * regarding utility, correctness, merchantability, or
 * fitness for a particular purpose.
 *
 * You have permission to use this software and to make
 * derivative products.  In all cases, you must retain
 * this notice in derivative products as well as credit
 * the source(s).
 * 
 * You may not use this software or any derivative of this
 * software in a commercial product without the express
 * written consent of StoutWare Engineering.
 * 
 * You may not use this software or any derivative of this software
 * in any application where failure of this software to perform as
 * intended would jeopardize the safety of any individual or property.
 * 
 * StoutWare Engineering will in no way be responsible for
 * any damages whatsoever arising out of your use of this
 * or any derivation of this product.
 **/

/*
 * The MotorControl interface defines a minimum
 * interface needed to implement effective motor
 * control.
 * 
 * Note that this interface applies to a single
 * motor.
 */
package motor;

public interface MotorControl {

    /**
     * 
     * @param ratio
     *            is clamped to the range of -1 to 1, representing full reverse
     *            and full forward, respectively. A value of zero means
     *            coasting. Invoking this method will turn off active braking,
     *            if active.
     */
    public void setPower(double ratio);

    /**
     * This sets active braking, if available. Otherwise, this has the same
     * effect as setPower( 0 ).
     */
    public void setBrake();

    /*
     * This sets the duty cycle (in milliseconds), for pulse-width-modulation
     * (PWM) control, if applicable. The cycle is split between the active (on)
     * and inactive (off) portions.
     */
    public void setDutyCycle(long interval);

}
