/**
 * @author Brace Stout
 * 
 * This software is copyright 2006, 2007 by StoutWare Engineering
 * All rights are retained.
 * 
 * This is example code only.  No representation is made
 * regarding utility, correctness, merchantability, or
 * fitness for a particular purpose.
 *
 * You have permission to use this software and to make
 * derivative products.  In all cases, you must retain
 * this notice in derivative products as well as credit
 * the source(s).
 * 
 * You may not use this software or any derivative of this
 * software in a commercial product without the express
 * written consent of StoutWare Engineering.
 * 
 * You may not use this software or any derivative of this software
 * in any application where failure of this software to perform as
 * intended would jeopardize the safety of any individual or property.
 * 
 * StoutWare Engineering will in no way be responsible for
 * any damages whatsoever arising out of your use of this
 * or any derivation of this product.
 **/

package motor;

import motor.MotorControl;
import motor.LoCoMoCo;

public class _TestLoCoMoCo {

    private static final String COMPORT = "COM4";
    private static final int TIMEOUT = 2000;

    /**
     * @param args
     */
    public static void main(String[] args) {

        LoCoMoCo mc = LoCoMoCo.open( COMPORT );

        if (mc == null) {
            System.out.println("Required COM port unavailable.");
            return;
        }

        MotorControl left = mc.getLeftMotorControl();
        MotorControl right = mc.getRightMotorControl();

        for ( int i = 1; i < 20; ++i ) {

            double lrand = 3 * Math.random();
            double rrand = 3 * Math.random();

            if ( lrand < 1 ) {
                left.setBrake();
            } else if ( lrand < 2 ) {
                left.setPower( -1.0 );
            } else {
                left.setPower( 1.0 );
            }
            
            if ( rrand < 1 ) {
                right.setBrake();
            } else if ( rrand < 2 ) {
                right.setPower( -1.0 );
            } else {
                right.setPower( 1.0 );
            }
            
            try {
                Thread.sleep( TIMEOUT );
            } catch (InterruptedException e) {
                break;
            }
            
        }

        left.setPower( 0.0 );
        right.setPower( 0.0 );

        mc.close();

        System.out.println("Normal program termination. ");
    }

}
